@@ -7,12 +7,12 @@ use utf8::all;
 my $txt = 'As  propostas  podem  ser  apresentadas  por  via  eletrónica,  mediante  registo  a  efetuar  no  portal  criado  pela  Câmara  Municipal  de  Guimarães  para  o  efeito  (http://op.cm-guimaraes.pt)  ou,  presencialmente,  em  Assembleias  Participativas.  No  OP_ESCOLAS’2015,  as  propostas  devem  ser  apresentadas  nas  Direções Escolares, em formulário próprio a disponibilizar para o efeito.';
 
 my $nlp = PLN::PT->new('http://api.pln.pt');
-my $data = $nlp->stopwords;
+my $data = $nlp->tf($txt, {stopwords=>1, term=>'lemma'});
 print Dumper $data;
 
 
 __END__
-my $data = $nlp->tf($txt);
+my $data = $nlp->stopwords;
 print Dumper $data;
 
 __END__
